@@ -6,10 +6,7 @@ class SingleResource:
     def __init__(self, resource):
         self.resource = Resource(resource)
         self.resource_path = resource['path']
-        if 'body' in resource:
-            body = resource['body']
-        else:
-            body = read_from_json(self.resource_path)
+        body = read_from_json(self.resource_path)
         self.body = remove_unnecessary_fields(body)
 
         self.keycloak_api = resource['keycloak_api']
